==> jc-1.4.0.tar.gz: soot/options/ShimpleOptions.h <==
// public class soot.options.ShimpleOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 80d7bce29bd94ae0 soot_options_ShimpleOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_ShimpleOptions_H_
#define _JC_soot_options_ShimpleOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_ShimpleOptions$sub_refs	_jc_soot_options_ShimpleOptions$sub_refs;
typedef struct _jc_soot_options_ShimpleOptions$sub_nonrefs	_jc_soot_options_ShimpleOptions$sub_nonrefs;
typedef struct _jc_soot_options_ShimpleOptions$refs	_jc_soot_options_ShimpleOptions$refs;
typedef struct _jc_soot_options_ShimpleOptions$nonrefs	_jc_soot_options_ShimpleOptions$nonrefs;
typedef struct _jc_soot_options_ShimpleOptions$object	_jc_soot_options_ShimpleOptions$object;

typedef struct _jc_soot_options_ShimpleOptions$fields_struct	_jc_soot_options_ShimpleOptions$fields_struct;
typedef const struct _jc_soot_options_ShimpleOptions$vmethods	_jc_soot_options_ShimpleOptions$vmethods;
typedef const struct _jc_soot_options_ShimpleOptions$vtable	_jc_soot_options_ShimpleOptions$vtable;
typedef const struct _jc_soot_options_ShimpleOptions$vtype	_jc_soot_options_ShimpleOptions$vtype;

// Class fields structure
struct _jc_soot_options_ShimpleOptions$fields_struct {
	jint	phi__5felim__5fopt__5fnone;
	jint	phi__5felim__5fopt__5fpost;
	jint	phi__5felim__5fopt__5fpre;
	jint	phi__5felim__5fopt__5fpre__5fand__5fpost;
};
extern _jc_soot_options_ShimpleOptions$fields_struct _jc_soot_options_ShimpleOptions$class_fields;

// Constructors
extern void _jc_soot_options_ShimpleOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_ShimpleOptions$method$debug$861416ee28c752ac(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);
extern jboolean _jc_soot_options_ShimpleOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);
extern jint _jc_soot_options_ShimpleOptions$method$phi__5felim__5fopt$9984de5ddee76333(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);
extern jboolean _jc_soot_options_ShimpleOptions$method$standard__5flocal__5fnames$c991dd14f58c6bab(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$debug$861416ee28c752ac;
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$phi__5felim__5fopt$9984de5ddee76333;
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$standard__5flocal__5fnames$c991dd14f58c6bab;

// Virtual methods structure
struct _jc_soot_options_ShimpleOptions$vmethods {
	jboolean	(*debug$861416ee28c752ac)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);
	jint	(*phi__5felim__5fopt$9984de5ddee76333)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);
	jboolean	(*standard__5flocal__5fnames$c991dd14f58c6bab)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *);
};

// Vtable
struct _jc_soot_options_ShimpleOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_ShimpleOptions$vmethods	soot_options_ShimpleOptions;
};

// Vtype
struct _jc_soot_options_ShimpleOptions$vtype {
	_jc_type			type;
	_jc_soot_options_ShimpleOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_ShimpleOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_ShimpleOptions$refs {
    _jc_soot_options_ShimpleOptions$sub_refs	soot_options_ShimpleOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_ShimpleOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_ShimpleOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_ShimpleOptions$sub_nonrefs	soot_options_ShimpleOptions;
};

// Object instance structure
struct _jc_soot_options_ShimpleOptions$object {
	_jc_soot_options_ShimpleOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_ShimpleOptions$vtype	*vtype;
	_jc_soot_options_ShimpleOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_ShimpleOptions$vtype _jc_soot_options_ShimpleOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_ShimpleOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_ShimpleOptions$class_object;

#endif	/* _JC_soot_options_ShimpleOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/ShimpleOptions.h <==
// public class soot.options.ShimpleOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 80d7bce29bd94ae0 soot_options_ShimpleOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_ShimpleOptions_H_
#define _JC_soot_options_ShimpleOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_ShimpleOptions$sub_refs	_jc_soot_options_ShimpleOptions$sub_refs;
typedef struct _jc_soot_options_ShimpleOptions$sub_nonrefs	_jc_soot_options_ShimpleOptions$sub_nonrefs;
typedef struct _jc_soot_options_ShimpleOptions$refs	_jc_soot_options_ShimpleOptions$refs;
typedef struct _jc_soot_options_ShimpleOptions$nonrefs	_jc_soot_options_ShimpleOptions$nonrefs;
typedef struct _jc_soot_options_ShimpleOptions$object	_jc_soot_options_ShimpleOptions$object;

typedef struct _jc_soot_options_ShimpleOptions$fields_struct	_jc_soot_options_ShimpleOptions$fields_struct;
typedef const struct _jc_soot_options_ShimpleOptions$vmethods	_jc_soot_options_ShimpleOptions$vmethods;
typedef const struct _jc_soot_options_ShimpleOptions$vtable	_jc_soot_options_ShimpleOptions$vtable;
typedef const struct _jc_soot_options_ShimpleOptions$vtype	_jc_soot_options_ShimpleOptions$vtype;

// Class fields structure
struct _jc_soot_options_ShimpleOptions$fields_struct {
	jint	phi__5felim__5fopt__5fnone;
	jint	phi__5felim__5fopt__5fpost;
	jint	phi__5felim__5fopt__5fpre;
	jint	phi__5felim__5fopt__5fpre__5fand__5fpost;
};
extern _jc_soot_options_ShimpleOptions$fields_struct _jc_soot_options_ShimpleOptions$class_fields;

// Constructors
extern void _jc_soot_options_ShimpleOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_ShimpleOptions$method$debug$861416ee28c752ac(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_ShimpleOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_options_ShimpleOptions$method$phi__5felim__5fopt$9984de5ddee76333(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_ShimpleOptions$method$standard__5flocal__5fnames$c991dd14f58c6bab(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$debug$861416ee28c752ac;
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$phi__5felim__5fopt$9984de5ddee76333;
extern _jc_method _jc_soot_options_ShimpleOptions$method_info$standard__5flocal__5fnames$c991dd14f58c6bab;

// Virtual methods structure
struct _jc_soot_options_ShimpleOptions$vmethods {
	jboolean	(*debug$861416ee28c752ac)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;
	jint	(*phi__5felim__5fopt$9984de5ddee76333)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*standard__5flocal__5fnames$c991dd14f58c6bab)(_jc_env *, struct _jc_soot_options_ShimpleOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_ShimpleOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_ShimpleOptions$vmethods	soot_options_ShimpleOptions;
};

// Vtype
struct _jc_soot_options_ShimpleOptions$vtype {
	_jc_type			type;
	_jc_soot_options_ShimpleOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_ShimpleOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_ShimpleOptions$refs {
    _jc_soot_options_ShimpleOptions$sub_refs	soot_options_ShimpleOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_ShimpleOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_ShimpleOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_ShimpleOptions$sub_nonrefs	soot_options_ShimpleOptions;
};

// Object instance structure
struct _jc_soot_options_ShimpleOptions$object {
	_jc_soot_options_ShimpleOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_ShimpleOptions$vtype	*vtype;
	_jc_soot_options_ShimpleOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_ShimpleOptions$vtype _jc_soot_options_ShimpleOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_ShimpleOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_ShimpleOptions$class_object;

#endif	/* _JC_soot_options_ShimpleOptions_H_ */
